@@ -23,8 +23,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <QTest>
 #include <QtCrypto>
-#include <QtTest/QtTest>
 
 #ifdef QT_STATICPLUGIN
 #include "import_plugins.h"
@@ -41,8 +41,9 @@ private Q_SLOTS:
     void testHexString();
     void testIncrementalUpdate();
     void testBrokenInput();
+
 private:
-    QCA::Initializer* m_init;
+    QCA::Initializer *m_init;
 };
 
 void HexUnitTest::initTestCase()
@@ -64,15 +65,17 @@ void HexUnitTest::testHexString_data()
     QTest::newRow("ABCD") << QStringLiteral("ABCD") << QStringLiteral("41424344");
     QTest::newRow("empty") << QString(QLatin1String("")) << QString(QLatin1String(""));
     QTest::newRow("abcddef") << QStringLiteral("abcddef") << QStringLiteral("61626364646566");
-    QTest::newRow("empty too") << QString::fromLatin1("\0") << QString::fromLatin1("");   // Empty QString. clazy:exclude=qstring-allocations
+    QTest::newRow("empty too") << QString::fromLatin1("\0") // clazy:exclude=qstring-allocations
+                               << QString::fromLatin1("");  // Empty QString. clazy:exclude=qstring-allocations
     QTest::newRow("BEL") << QStringLiteral("\a") << QStringLiteral("07"); // BEL
-    QTest::newRow("BS") << QStringLiteral("\b") << QStringLiteral("08"); // BS
-    QTest::newRow("HT") << QStringLiteral("\t") << QStringLiteral("09"); // HT
-    QTest::newRow("LF") << QStringLiteral("\n") << QStringLiteral("0a"); // LF
-    QTest::newRow("VT") << QStringLiteral("\v") << QStringLiteral("0b"); // VT
-    QTest::newRow("FF") << QStringLiteral("\f") << QStringLiteral("0c"); // FF
-    QTest::newRow("CR") << QStringLiteral("\r") << QStringLiteral("0d"); // CR
-    QTest::newRow("bug126735") << QStringLiteral("@ABCDEFGHIJKLMNO") << QStringLiteral("404142434445464748494a4b4c4d4e4f");
+    QTest::newRow("BS") << QStringLiteral("\b") << QStringLiteral("08");  // BS
+    QTest::newRow("HT") << QStringLiteral("\t") << QStringLiteral("09");  // HT
+    QTest::newRow("LF") << QStringLiteral("\n") << QStringLiteral("0a");  // LF
+    QTest::newRow("VT") << QStringLiteral("\v") << QStringLiteral("0b");  // VT
+    QTest::newRow("FF") << QStringLiteral("\f") << QStringLiteral("0c");  // FF
+    QTest::newRow("CR") << QStringLiteral("\r") << QStringLiteral("0d");  // CR
+    QTest::newRow("bug126735") << QStringLiteral("@ABCDEFGHIJKLMNO")
+                               << QStringLiteral("404142434445464748494a4b4c4d4e4f");
 }
 
 void HexUnitTest::testHexString()
@@ -80,8 +83,8 @@ void HexUnitTest::testHexString()
     QCA::Hex hexObject;
     QFETCH(QString, raw);
     QFETCH(QString, encoded);
-    QCOMPARE( hexObject.encodeString(raw), encoded);
-    QCOMPARE( hexObject.decodeString(encoded), raw);
+    QCOMPARE(hexObject.encodeString(raw), encoded);
+    QCOMPARE(hexObject.decodeString(encoded), raw);
 }
 
 void HexUnitTest::testIncrementalUpdate()
@@ -91,19 +94,19 @@ void HexUnitTest::testIncrementalUpdate()
     hexObject.setup(QCA::Encode);
     hexObject.clear();
     QCA::SecureArray result1 = hexObject.update(QCA::SecureArray("ab"));
-    QVERIFY( hexObject.ok() );
-    QCOMPARE( result1[0], '6' );
-    QCOMPARE( result1[1], '1' );
-    QCOMPARE( result1[2], '6' );
-    QCOMPARE( result1[3], '2' );
+    QVERIFY(hexObject.ok());
+    QCOMPARE(result1[0], '6');
+    QCOMPARE(result1[1], '1');
+    QCOMPARE(result1[2], '6');
+    QCOMPARE(result1[3], '2');
     QCA::SecureArray result2 = hexObject.update(QCA::SecureArray("cd"));
-    QCOMPARE( hexObject.ok(), true );
-    QCOMPARE( result2[0], '6' );
-    QCOMPARE( result2[1], '3' );
-    QCOMPARE( result2[2], '6' );
-    QCOMPARE( result2[3], '4' );
-    QCOMPARE( QCA::SecureArray(), QCA::SecureArray(hexObject.final()) );
-    QCOMPARE( hexObject.ok(), true );
+    QCOMPARE(hexObject.ok(), true);
+    QCOMPARE(result2[0], '6');
+    QCOMPARE(result2[1], '3');
+    QCOMPARE(result2[2], '6');
+    QCOMPARE(result2[3], '4');
+    QCOMPARE(QCA::SecureArray(), QCA::SecureArray(hexObject.final()));
+    QCOMPARE(hexObject.ok(), true);
 }
 
 void HexUnitTest::testBrokenInput()
