@@ -23,8 +23,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include <QTest>
 #include <QtCrypto>
-#include <QtTest/QtTest>
 
 #include <limits>
 
@@ -37,12 +37,18 @@ class TestClass1 : public QObject
     Q_OBJECT
 
 public:
-    TestClass1() {};
+    TestClass1()
+    {
+    }
     TestClass1(const TestClass1 &)
-        : QObject(nullptr) {};
+        : QObject(nullptr)
+    {
+    }
 
 public Q_SLOTS:
-    void    voidMethod() {};
+    void voidMethod()
+    {
+    }
     QString qstringMethod()
     {
         return QString();
@@ -182,7 +188,7 @@ void MetaTypeUnitTest::returnTypeTest()
 
 void MetaTypeUnitTest::invokeMethodTest()
 {
-    TestClass1 * testClass1 = new TestClass1;
+    TestClass1  *testClass1 = new TestClass1;
     QVariantList args;
 
     bool ret;
